::: laktory.models.PulumiResource
    options:
        show_bases: false
---

::: laktory.models.resources.pulumiresource.pulumi_resources
---

::: laktory.models.resources.pulumiresource.pulumi_outputs
